@@ -257,6 +257,8 @@ class Case(BaseModel):
         return similar_cases_df
 
     def explainability_gradcam(self):
+        if not self.image_data.get("gradcam", None):
+            return "No Gradcam method found for this case"
         fig = go.Figure()
 
         fig.add_layout_image(
@@ -316,6 +318,8 @@ class Case(BaseModel):
         fig.show(config={"displaylogo": False})
 
     def explainability_shap(self):
+        if not self.image_data.get("shap", None):
+            return "No Shap method found for this case"
         fig = go.Figure()
 
         fig.add_layout_image(
@@ -342,6 +346,8 @@ class Case(BaseModel):
         fig.show(config={"displaylogo": False})
 
     def explainability_lime(self):
+        if not self.image_data.get("lime", None):
+            return "No Lime method found for this case"
         fig = go.Figure()
 
         fig.add_layout_image(
@@ -368,6 +374,8 @@ class Case(BaseModel):
         fig.show(config={"displaylogo": False})
 
     def explainability_integrated_gradients(self):
+        if not self.image_data.get("integrated_gradients", None):
+            return "No Integrated Gradients method found for this case"
         fig = go.Figure()
 
         fig.add_layout_image(
@@ -498,7 +506,8 @@ class CaseText(BaseModel):
     status: str
     prompt: str
     output: str
-    explainabiblity: Optional[Dict] = {}
+    explainability: Optional[Dict] = {}
+    audit_trail: Optional[Dict] = {}
 
     def prompt(self):
         """Get prompt"""
@@ -515,7 +524,7 @@ class CaseText(BaseModel):
         :return: raw data dataframe
         """
         raw_data_df = (
-            pd.DataFrame([self.explainabiblity.get("feature_importance", {})])
+            pd.DataFrame([self.explainability.get("feature_importance", {})])
             .transpose()
             .reset_index()
             .rename(columns={"index": "Feature", 0: "Value"})
@@ -526,7 +535,7 @@ class CaseText(BaseModel):
     def explainability_feature_importance(self):
         """Plots Feature Importance chart"""
         fig = go.Figure()
-        feature_importance = self.explainabiblity.get("feature_importance", {})
+        feature_importance = self.explainability.get("feature_importance", {})
 
         if not feature_importance:
             return "No Feature Importance for the case"
@@ -565,24 +574,23 @@ class CaseText(BaseModel):
         fig.show(config={"displaylogo": False})
 
     def network_graph(self):
-        network_graph_data = self.explainabiblity.get("network_graph", {})
+        network_graph_data = self.explainability.get("network_graph", {})
         if not network_graph_data:
             return "No Network graph found for this case"
         base64_str = network_graph_data
         try:
             img_bytes = base64.b64decode(base64_str)
             image = Image.open(BytesIO(img_bytes))
-            image.show()
             return image
         except Exception as e:
             print(f"Error decoding base64 image: {e}")
             return None
         
     def token_attribution_graph(self):
-        relavance_data = self.explainabiblity.get("relavance", {})
-        if not relavance_data:
+        relevance_data = self.explainability.get("relevance", {})
+        if not relevance_data:
             return "No Token Attribution graph found for this case"
-        base64_str = relavance_data
+        base64_str = relevance_data
         try:
             img_bytes = base64.b64decode(base64_str)
             image = Image.open(BytesIO(img_bytes))
@@ -590,4 +598,7 @@ class CaseText(BaseModel):
         except Exception as e:
             print(f"Error decoding base64 image: {e}")
             return None
+        
+    def audit(self):
+        return self.audit_trail
     
\ No newline at end of file
